%
% CompObj : composite object, made of optics and propagators
%
% November 20th, 2013  Hiro Yamamoto
%

classdef CompObj < handle
    
    properties
        name = 'unnamed'

        % each port is assigned a unique number, which is the field index
        inPorts
        outPorts
        
        % path of the closed loop
        pathLoop
        % lock path
        lockPropID
        % accelaration code
        Nacc = 2;
        Nave = 0;
        
        % handle of parent
        cavities
    end
    
    % function to replace a static variable
    methods
        % pathRec = struct('srcID', 0, 'action', 0, 'id', 0, 'index', 0, 'sinkID', 0)
        %    src field ID
        %    action : (1) propagation or 
        %             (2) reflection or 
        %             (3) transmision
        %       prop : propID
        %       reflection : optic ID, inPort index
        %       transmission : optic ID, inport index
        %    sink field ID

        % constructor
        function obj = CompObj( name, bookID, cavities )

            obj.name = name;
            obj.pathLoop = cavities.pathBook{1, bookID};
            obj.cavities = cavities;

            obj.digestPath( bookID )
        end
        
        function [err, numTry] = calc( obj, lock, printIt, err )
            if ~exist( 'err', 'var' )
                err = 1e-6;
            end
            if lock
                propID = obj.lockPropID;
            else
                propID = 0;
            end
            [err, numTry] = obj.cavities.AccClosedCavityStationary( ...
                                obj.pathLoop, 0, err, propID, obj.Nacc, obj.Nave, printIt );
        end
        
        % digest the path
        function digestPath( obj, bookID )
            obj.lockPropID = 0;
            pathRec = obj.cavities.pathBook{2, bookID};
            % find lock propagator ID
            for ip = 1:length(pathRec)
                if pathRec(ip).action == 1
                    if obj.lockPropID == 0
                        % use the first propagator as lock length
                        obj.lockPropID = pathRec(ip).id;
                    end
                    [inPort, outPort] = ...
                        obj.cavities.findConnectedInOutPort( pathRec(ip).srcID );
                    if inPort > 0 && isempty( find(obj.inPorts == inPort, 1) )
                        obj.inPorts( length(obj.inPorts)+1 ) = inPort;
                    end
                    if outPort > 0 && isempty( find(obj.outPorts == outPort, 1) )
                        obj.outPorts( length(obj.outPorts)+1 ) = outPort;
                    end
                    [inPort, outPort] = ...
                        obj.cavities.findConnectedInOutPort( pathRec(ip).sinkID );
                    if inPort > 0 && isempty( find(obj.inPorts == inPort, 1) )
                        obj.inPorts( length(obj.inPorts)+1 ) = inPort;
                    end
                    if outPort > 0 && isempty( find(obj.outPorts == outPort, 1) )
                        obj.outPorts( length(obj.outPorts)+1 ) = outPort;
                    end
               end
            end
        end
        
        function info = printInfo( obj )
            info = sprintf('name: ''%s'',  lock propID = %d,  Nacc = %d,  Nave = %d\ninPorts = [ ', ...
                obj.name, obj.lockPropID, obj.Nacc, obj.Nave );
            for ii = 1:length( obj.inPorts )
                info = sprintf('%s%d ', info, obj.inPorts(ii));
            end
            info = sprintf('%s],  outPorts = [ ', info);
            for ii = 1:length( obj.outPorts )
                info = sprintf('%s%d ', info, obj.outPorts(ii));
            end
            info = sprintf('%s]\ncavity path = [ ', info);
            for ii = 1:length( obj.pathLoop )
                info = sprintf('%s%d ', info, obj.pathLoop(ii));
            end
            info = sprintf('%s]\n', info);
        end

    end
    
end