%
% mirror2x2 : mirror with fields of normal incidence
%
% August 5th, 2014
%   removeCurvature option is added to Mirror2x2
%
%   April 4, 2014
%       When finite optTheta, optPhi is set by addMirror, they were applied in the code
%       Only when tile removal was applied, they were used.
%       Fixed, always applied.
%
%   September 13, 2013
%
%             HR     AR
%  inPort 1  ==> || | ==> outPort 2
%                || |
%  outPort 1 <== || | <== inPort 2
%
%
% September 2, 2015
%    Using new OpticObj structure with ifo property, mostly
%    changing ConstantTK.kLam0 to obj.ifo.fields.kCR
%
%

classdef Mirror2x2Obj < MirrorObj
    
	properties (Constant)
        inputNames2x2 = { 'invRoCAR', 'removeTilt', 'removeCurvature' };
    end
    
    methods (Static)
        function tagList = getInputNames
            tagList = [ Mirror2x2Obj.inputNames2x2, MirrorObj.getInputNames ];
        end
    end
    
    methods
        function obj = Mirror2x2Obj( name, ifo, specs )
            
            obj = obj@MirrorObj( ifo, 2, 2, name, specs );
            
            UtilTK.updateProperties( obj, obj.inputNames2x2, specs );

            obj.suffix = {'HR', 'AR'};

            obj.reflMatch  = [1, 2];
            obj.transMatch = [2, 1];
                        
            obj.updateNdep;
 
        end
        
        function updateNdep( obj, ~, ~ )
            % lens and prop do not commute, but will be OK
            transM = MMTK.LensF_ABCD( obj.invFocal ) * MMTK.Prop_ABCD( obj.Thickness, obj.nRef );
            lensM = MMTK.LensR_ABCD( obj.invRoC + obj.invRoCAR, obj.nRef );
            obj.reflABCD(1:2) = { MMTK.Refl_ABCD( obj.invRoC ), ...
                transM * MMTK.ReflAR_ABCD( obj.invRoC, obj.nRef ) * transM };
            obj.transABCD(1:2) = { transM * lensM, lensM * transM };
        end
        
        % build maps for standard mirror
        % it takes into account the incident angle and the maps are stored in reflFFT and transFFT
        % just for 2x2 mirrors
        % for finite angle incident angle case, they need to be properly refilled into other buffer
        % obj.RPYmap etc are used and kept for debugging purpose
        function buildMaps( obj )
 
            % load three maps
            [ obj.RPYmap, obj.RSXmap, obj.TPXmap, obj.TSYmap, specified ] = obj.prepare2x2Like;
            if ~specified
            	[ obj.RPYmap, obj.RSXmap, obj.TPXmap, obj.TSYmap ] = obj.buildDefault;
            end

            % mask is always 0, and side is only one for each
            obj.buildMirFFTmaps( [0,0,0,0], [1;2;1;2] );
            
% mirror orientation by (optPhi, optTheta) applied here
            obj.doRemoveTiltCurvature( true );
            
        end
    end
end
