function datOut = extendOuterside( datIn, xl, yl, rfit, rout, indMax )
% function datOut = extendOuterside( datIn, xl, yl, rfit, rout, indMax )
% fit dat in radius of rfit using zernikeCoef the index of indMax
% use the coefficient to expand data in the ring between r = rfit ~ rout

% December 17, 2014  Hiro Yamamoto
%   inital code

if ~exist( 'indMax', 'var' ) || indMax == 0
    % using smaller index seems to be better than using a large index, like 17.
    indMax = 4;
end

% calculate the zernite terms
% -indMax means : for positive indMax, use all (0,0),(1,-1),(1,1),...,(indMax,-indMax) ...,(indMax,indMax)
%               : for negative indexMax, use lower order wyko indexes from 0 to (-indMax)
[datOut, coef, nmList] = zernikeCoef( datIn, xl, yl, rfit, -indMax, 1, false );

if size(xl,2) == 1
    xl = xl';
end
if size(yl,1) == 1
    yl = yl';
end
[xg, yg] = meshgrid(xl(1,:), yl(:,1));

% fill outside with an evarage value using available data around the edge
rg = sqrt( xg.^2 + yg.^2 );
ave = mean( datOut( rg < rfit & rg > rfit*0.9 & ~isnan( datOut ) ) );
datOut( rg < rout & isnan(datOut) ) = ave;

% datOut is real data - zernite terms within r < rfit.
% add sum of zernike terms calculated in r < rout
indR = find( rg < rout );
for inmI = 1 : length(nmList)
    ZfuncI = zernikeFunc( nmList(inmI,1), nmList(inmI,2), ...
        rg/rfit, atan2(yg, xg), false );
    datOut(indR) = datOut(indR) + coef(inmI) * ZfuncI(indR);
end
