function [f,psd] = map2PSD1D( fileName, mirrorAperture, rxy, powerFitAperture, removeZernike )
% function [f,psd] = map2PSD1D( fileName, mirrorAperture, rxy, powerFitAperture, removeZernike )
% now uses LMA version of PSD calculator, supports windowed PSD(r)
% rxy = 0, 1, 2 for PSD(r) integrating over phi, PSD(x) integrating over y and PSD(y)
% powerFitAperture : power and tilt are moved using Zernite fit in this aperture
% when removeZernike is specified, zernikeCoef is used to remove more zernike terms.

if ~exist( 'rxy', 'var' )
    rxy = 0;
end
if ~exist( 'powerFitAperture', 'var' )
    powerFitAperture = 0.16;
end
[amap, xl, yl] = loadOneDataFile( fileName, mirrorAperture, powerFitAperture, 2 );
if exist( 'removeZernike', 'var' )
    amap = zernikeCoef( amap, xl, yl, mirrorAperture/2, removeZernike );
end 
[f, psd] = LMA_PSD( amap, xl, yl, mirrorAperture, rxy );
