% [fSum, x, y] = zernikeSum( coef, NMlist, normRadius, x, y, outRadius )
% calculate sum of zernike terms with normalization radius of normRadius at (x, y) within radius of outRadius
%    fSum = sum( coef( n, m ) * zernike( n, m, x/nr, y/nr ) )
% [x,y] on output are 2 d matrix, and fSum are nan outside of x^2+y^2 > outRadius^2
% coef are used with unnormalized zernike functions.
%
function [fSum, x, y] = zernikeSum( coef, NMlist, normRadius, x, y, outRadius )

if min( size(x) ) == 1
    if size(x,2) == 1
        x = x';
    end
end
if min( size(y) ) == 1
    if size(y,2) == 1
        y = y';
    end
end
if size(x,1) == 1 && size(y,1) == 1
    [x,y] = meshgrid( x, y );
elseif size(x) ~= size(y)
    error( 'size x (%d,%d) and size y (%d,%d) are different\n', size(x,1), size(x,2), size(y,1), size(y,2));
end

fSum = zeros( size(x) );
r = sqrt(x.^2 + y.^2);
r( r > outRadius ) = nan;
r = r/normRadius;
theta = atan2( y, x );
for inm = 1 : length( coef )
    if coef(inm) ~= 0
        fSum = fSum + coef(inm) * zernikeFunc( NMlist(inm,1), NMlist(inm,2), r, theta, false );
    end
end

% nonZero = find( coef ~= 0 );
% for ind = 1:size(x,1)*size(x,2)
%     rsq = x(ind)^2 + y(ind)^2;
%     if rsq < outRadius^2
%         fSum(ind) = 0;
%         r = sqrt(rsq) / normRadius;
%         theta = atan2( y(ind), x(ind) );
%         for inz = 1 : length(nonZero)
%             inm = nonZero(inz);
%             fSum(ind) = fSum(ind) + coef(inm) * zernikeFunc( NMlist(inm,1), NMlist(inm,2), r, theta, false );
%         end
%     end
% end
% 
    