%% create FP cavity based on FFTIFO
classdef FPIFOThermal < FFTIFO
    
    methods
        function obj = FPIFOThermal( varargin )
            obj@FFTIFO( varargin{:} );
        end

        function defineIFO( obj, varargin )
            power = 1;
            eval( UtilTK.setVars( who, true, varargin{:} ) );

            %% add optics
            %  help FFTIFO.addMirror lists all avairable parameters
            RoCITMX = 1934;
            RoCETMX = 2245;
            % laser source
            obj.addLaser( 'src', power );
            % ITM
            obj.addMirror( 'ITMX', 'invRoC', 1/RoCITMX, 'Aperture', 0.326, 'Thick', 0.2, ...
                'T', 1.48e-2, 'Lhr', 10.4e-6, 'Lar', (164+42)*1e-6, 'removeTilt', true );
            % ETM
            obj.addMirror( 'ETMX', 'invRoC', 1/RoCETMX, 'Aperture', 0.326, 'Thick', 0.2, ...
                'T', 3.7e-6, 'Lhr', 10.9e-6, 'resolution', 2e-3, 'removeTilt', true );
            % detection port
            obj.addDetector( 'trans' );
            
            %% define connections among optics
            obj.addProp( '', 'src', 'ITMX-AR' );
            obj.addProp( 'FPprop', 'ITMX-HR', 'ETMX-HR', 3994.5);
            obj.addProp( '', 'ETMX-AR', 'trans' );
            
            %% modify the defintions of test masses
            %  help FFTIFO.setHRfiles explains arguments
            %  setHRfiles defines the height of HR surface.
            %  To add a concave curvature, use r^2/(2*RoC) with RoC > 0.
            obj.setHRfiles( 'ITMX', './Data/ITM04_CITZygo.dat', ...
                'map + calcThermal(0, r, PsubIX, PcoatIX, wIX, 0.2, 0.17 ) + r.^2/2*invRoCITMXRH', ...
                0.16, RoCITMX, 0, 'PsubIX', 0', 'PcoatIX', 0, 'wIX', 0.0531, 'invRoCITMXRH', 0 );
            
            %  setTRfiles defines the transmission map, which is negative is optical path length
            %  To add a converging lens, use r^2/(2*RoC) with RoC > 0
            obj.setTRfiles( 'ITMX', '', ...
                '-calcThermal(1, r, PsubIX, PcoatIX, wIX, 0.2, 0.17 ) + r.^2/2*invRoCITMXCP', ...
                0.16, 0, 0, 'PsubIX', 0', 'PcoatIX', 0, 'wIX', 0.0531, 'invRoCITMXCP', 0 );
            
            obj.setHRfiles( 'ETMX', './Data/ETM07_CIT.dat', ...
                'map + calcThermal(0, r, 0, PcoatEX, wEX, 0.2, 0.17 ) + r.^2/2*invRoCETMXRH', ...
                0.16, RoCETMX, 0, 'PcoatEX', 0, 'wEX', 0.062, 'invRoCETMXRH', 0 );

        end
    end
end
