%% create FP cavity based on FFTIFO
%
%  arm = 'X' or 'Y' for X and Y arm, other characters without map
%
classdef FPIFOv < FFTIFO
    
    methods
        function obj = FPIFOv( varargin )
            obj@FFTIFO( varargin{:} );
        end
        %% this defines the IFO configuration
        function defineIFO( obj, varargin )

            % set arm = 'X' or 'Y' to simulate X or Y arm  
            PcoatI = 0;
            PsubI = 0;
            PcoatE = 0;
            
            mapWeight = 1;
            extraArmLoss = 40e-6;
            power = 1;
            fieldMode = 'HG';
            ind1 = 0;
            ind2 = 0;
            arm = 'Y'; 
            Aperture = 0.326;
            ITMErr = 0;  % error estimation by map - map(rotation)
            ETMErr = 0;
            ITMID = 0;
            ETMID = 0;
            withMapI = true;
            withMapE = true;
            TITMscale = 1;
            EITMscale = 1;
            swapIERoC = false;
            x0 = 0;
            y0 = 0;
            tiltX = 0;
            tiltY = 0;
            optPhi = 0;
            optTheta = 0;
            
            ITMRoC0 = 1934;
            ETMRoC0 = 2245;
            Lcav = 3994.5;
            
                        % default is Y
            ITMdat = './Data/ITM08_CITZygo.dat';
            ETMdat = './Data/ETM09_CIT.dat';
%           ETMdat = './Data/ETM14_CIT.dat';
%           CASIdat = '/Users/hiro/Dropbox/COC/LMA new coating/C14105.txt';
            CASIdat = '';

            % fp = FPIFOv('arm', 'X') or fp = FPIFOv( 'ETMdat', 'dataFileWithPath.dat')
            eval( UtilTK.setVars( who, true, varargin{:} ) );

            if strcmp(arm, 'SP')
                ETMdat = './Data/ETM9_SP_N800_W316500um.txt';
                arm = 'Y';
            elseif strcmp(arm, 'ABR')
                ETMdat = './Data/ETM9_ABR_N800_W316500um.txt';
                arm = 'Y';
            end

            if arm == 'X'
            	ITMdat = './Data/ITM04_CITZygo.dat';
                ETMdat = './Data/ETM07_CIT.dat';
%                ETMdat = '/Users/hiro/Desktop/COC/LMA new coating/ETM14/c14048_etm14_avge31-45_subref_276.dat';
                ITMRoC = 1937.9;
                ETMRoC = 2239.7;
                ITMLoss = 10.4e-6;
                ETMLoss = 10.9e-6;
                ITMT = 1.48e-2 * TITMscale;
                ETMT = 3.7e-6;
            elseif arm == 'Y'
                ITMRoC = 1940.7;
                ETMRoC = 2242.4;
                ITMLoss = 14.3e-6;
                ETMLoss = 9.3e-6;
                ITMT = 1.48e-2 * TITMscale;
                ETMT = 3.6e-6;
            else
                extraArmLoss = 0;
                ITMdat = '';
                ETMdat = '';
                ITMRoC = ITMRoC0;
                ETMRoC = ETMRoC0;
                ITMLoss = 0;
                ETMLoss = 0;
                ITMT = 1.48e-2 * TITMscale;
                ETMT = 5e-6 * EITMscale;
            end
            
            if strcmp( arm, 'LLOX' )
                ITMID = 4;
                ETMID = 7;
            elseif strcmp( arm, 'LLOY' )
                ITMID = 8;
                ETMID = 9;
            elseif strcmp( arm, 'LHOX' )
                ITMID = 3;
                ETMID = 8;
            elseif strcmp( arm, 'LHOY' )
                ITMID = 11;
                ETMID = 12;
            end
            
            switch ITMID
                case 4
                    ITMdat = './Data/ITM04_CITZygo.dat';  % LLO X
                    ITMRoC = 1937.9;
                case 8
                    ITMdat = './Data/ITM08_CITZygo.dat';  % LLO Y
                    ITMRoC = 1940.7;
                case 3
                    ITMdat = './Data/ITM03_CIT.dat';   % LHO X
                    ITMRoC = 1939.3;
                case 11
                    ITMdat = './Data/ITM11_CIT.dat';   % LHO Y
                    ITMRoC = 1939.20;
            end
            switch ETMID
                case 7
                    ETMdat = './Data/ETM07_CIT.dat';  % LLO X
                    ETMRoC = 2239.7;
                case 9
                    ETMdat = './Data/ETM09_CIT.dat';  % LLO Y
                    ETMRoC = 2242.4;
                case 8
                    ETMdat = './Data/ETM08_CIT.dat';  % LHO X
                    ETMRoC = 2251.54;
                case 12
                    ETMdat = './Data/ETM12_CIT.dat';  % LHO X
                    ETMRoC = 2238.9;
            end
            
            if swapIERoC
                temp = ITMRoC;
                ITMRoC = ETMRoC;
                ETMRoC = temp;
            end
            
            % ITM and ETM IDs, with new line
            if exist('ITMID', 'var')
                fprintf(1,'ITMID = %d     ', ITMID    );
            end
            if exist('ETMID', 'var')
                fprintf(1,'ETMID = %d', ETMID );
            end
            if exist('ITMID', 'var') || exist('ETMID', 'var')
                fprintf(1,'\n');
            end
            
            % if maps are not be to used, nulify them
            if ~withMapI
                ITMdat = '';
            end
            if ~withMapE
                ETMdat = '';
            end
            
            removeTilt = (optTheta == 0) & (tiltX == 0) & (tiltY == 0);
            
            %% add optics
            % laser source
            obj.addLaser( 'src', 'power', power, 'fieldMode', fieldMode, 'ind1', ind1, 'ind2', ind2 );
            
            % ITM
            obj.addMirror( 'ITM', 'invRoC', 1/ITMRoC, 'Aperture', Aperture, 'Thick', 0.2, ...
                'T', ITMT, 'Lhr', ITMLoss + extraArmLoss/2, 'removeTilt', removeTilt );
            % ETM
            obj.addMirror( 'ETM', 'invRoC', 1/ETMRoC, 'Aperture', Aperture, 'Thick', 0.2, ...
                'T', ETMT, 'Lhr', ETMLoss + extraArmLoss/2, 'resolution', 2e-3, 'removeTilt', removeTilt, ...
                'optX0', x0, 'optY0', y0, 'optTheta', optTheta, 'optPhi', optPhi );
            
            % detector behind ETM
            obj.addDetector( 'trans' );
            
            %% define connections among optics
            obj.addProp( '', 'src', 'ITM-AR' );
            obj.addProp( 'FPprop', 'ITM-HR', 'ETM-HR', Lcav);
            obj.addProp( '', 'ETM-AR', 'trans' );
            
            %% use the measured maps
            fprintf(1, 'ITM map = ''%s'', ETM map = ''%s''\n', ITMdat, ETMdat );

            % ITM HR surface
%            obj.setHRfiles( 'ITM', ITMdat, 'map*mapWeight+x*tiltI+calcThermal(0, r, PsubI, PcoatI, wI, 0.2, 0.17 )', 0.16, ITMRoC, 0, 'tiltI', 0, 'mapWeight', mapWeight,'PsubI', PsubI, 'PcoatI', PcoatI, 'wI', 0.0531);
            obj.setHRfiles( 'ITM', ITMdat, 'map*mapWeight+x*tiltI', 0.16, ITMRoC, 0, 'tiltI', 0, 'mapWeight', mapWeight );
            obj.setHRfiles( 'ITM', '', 'calcThermal(0, r, PsubI, PcoatI, wI, 0.2, 0.17 )', 0.16, 1e20, 0, 'PsubI', PsubI, 'PcoatI', PcoatI, 'wI', 0.0531);
            if ITMErr ~= 0
                obj.setHRfiles( 'ITM', './Data/ITM08_even-odd_max_error.dat', 'map*ITMErr', 0, 0, 0, 'ITMErr', ITMErr  );
            end
            % ITM transmission maps
            % for mode scan, this is not necessary
%            obj.setTRfiles( 'ITM', './Data/itm04_sptwe.dat', '', 0.16, 302.41e3);
            % ETM HR surface
            if ~isempty( CASIdat )
                func = sprintf( 'zernikeCoef(fit1dData(''%s'', xl*1000, yl*1000, 0.16*1000 )*6e-8,xl,yl,0.08)', CASIdat );
                obj.setHRfiles( 'ETM', '', func, 0, 0 );
            elseif ~isempty( ETMdat )
 %               obj.setHRfiles( 'ETM', ETMdat, 'map*mapWeight+x*tiltX+y*tiltY+calcThermal(0, r, 0, PcoatE, wE, 0.2, 0.17 )', 0.16, ETMRoC, 0, 'tiltX', tiltX, 'tiltY', tiltY, 'mapWeight', mapWeight, 'PcoatE', PcoatE, 'wE', 0.062 );
                obj.setHRfiles( 'ETM', ETMdat, 'map*mapWeight+x*tiltX+y*tiltY', 0.16, ETMRoC, 0, 'tiltX', tiltX, 'tiltY', tiltY, 'mapWeight', mapWeight );
                obj.setHRfiles( 'ETM', '', 'calcThermal(0, r, 0, PcoatE, wE, 0.2, 0.17 )', 0.16, 1e20, 0, 'PcoatE', PcoatE, 'wE', 0.062 );
            end

            %%
            if ETMErr ~= 0
                obj.setHRfiles( 'ETM', './Data/ETM09_even-odd_max_error.dat', 'map*ETMErr', 0, 0, 0, 'ETMErr', ETMErr  );
            end
        end
    end
end
