classdef FPloss < FFTIFO
    
    methods 
        %% This is the code to define interferometer
        function defineIFO( obj )
            g = 0.997; Leng = 1.997; 
            w = sqrt( Leng * 1.064e-6 / pi / sqrt(1-g^2) )
            RoC = Leng/(1-g)
            A = 8*w
            
            %% add optics
            obj.addLaser( 'src' );
        	obj.addMirror( 'ITM', 'invRoC', 1/RoC , 'Aperture', A, 'T', 1e-3, 'Thickness', 0, 'virtual', 12*w );
        	ETMID = obj.addMirror( 'ETM', 'invRoC', 1/RoC , 'Aperture', A, 'T', 1e-6, 'virtual', 12*w );
            obj.addDetector( 'trans' );

            %% define propagations by specifying a pair of mirror and its port ID
            % [idf, idb] = addProp( obj, name, fromOpt, fromPort, toOpt, toPort, L0, delL )
            obj.addProp( '', 'src', 1, 'ITM', 2 );
        	obj.addProp( 'FPprop', 'ITM',  1, 'ETM', 1, Leng);
            obj.addProp( '', 'ETM', 2, 'trans', 1 );
            
            %% define details of ETM
            obj.optics.optList(ETMID).HRfiles.addMap( '', 'sqrt(2)*1e-9*cos(2*pi*x/lamx)', 0, 0, 0, 'lamx', 0.75e-3 );
            % set the resolution on ETM
   	        obj.optics.optList(ETMID).resolution = 0.5e-4;
        end
    end
end

