% this calculates quantities with cavity length locked + del
% length offset and the scan frequency are related as
% delF = c / lambda(1.064e-6) / arm length (3994.5) * delL = 7.0537e10 * delL

function out = FPscan( fp, del )

% lock FP
fp.lock;

% FPprop ID
propID = fp.props.findNamedProp( 'FPprop' );

% locked length
delL0 = fp.props.propList(propID).delL;

% number of scan length
Ndel = length(del);

% prepare output buffer
out = zeros(Ndel,13);

PDlocs =  [0.144,0.140; -0.144, 0.419; -0.430, 0.0714; -0.144, -0.148];
rPD = 0.0055;

for il = 1:Ndel
    % set the cavity length to be the locked length + del
    fp.props.setDelL( propID, delL0 + del(il) );
    % calculate fields using the locked length
    fp.calc(0,0); % default accuracy, no process report
    
    % now fields are caculated in a cavity with length = locked + del(il) or frequency 7.0537e10 * del(il)
    % To calculate HG compinent, HG = fp.HGCoef(0:m,0:n) will return HGmn amplitudes
    % To calculate LG compinent, LG = fp.LGCoef(0:p,0:m) will return LGpm amplitudes
    % this example calculates LG modes
    LG = fp.LGFrac('ETM-HR-o',0:5,0);  % LG(n,0), n = 0:5
    % this returns power
    P = fp.power('ETM-HR-o');
    % cavity length
    out(il,1) = delL0 + del(il);
    % total power
    out(il,2) = P;
    % 1 - LG(0,0), i.e., HOM fraction
    out(il,3) = abs(LG(1)).^2;
    % LG(2:6) = LGCoef(0,1:5), i.e., LG(0,1), LG(0,2), ...
    out(il,4:8) = abs(LG(2:6)).^2;
    % round trip loss
    out(il,9) = fp.roundtripLoss('ETM-HR-o');   % round trip loss of a cavity
    
    if mod(il, 10) == 1
        fprintf(1, '%d th event, power = %d\n', il, P );
    end
    
    [EI, xI] = fp.getField('ITM-HR-i', 1.6);
    out(il,10:13) = evalPD( EI, xI, rPD, PDlocs(:,1), PDlocs(:,2));
end
