% for the case IMCIFO is modified, clear imc and run
clear imc; imc = IMCIFO;
% print all information about IMC
% find the index of field of interest
imc.printAll
% lock the triangular cavity and calculate circulating fields
[err, numTry, pathLoop, propID] = imc.calc( true )
% this is the current locked length
del0 = imc.props.propList(propID).delL
% print information about the field from MC1 to MC3
imc.fields.fieldList(7).gaussFit
% 
% calculate HG(0:2,0:2) coefficient at various cavity length, HLGCoef also works
Cmn = imc.fields.fieldList(7).HGCoef(0:2,0:2);
% power fraction of HG modes
abs(Cmn).^2 / imc.fields.fieldList(7).calcPower
% scan as a function of cavity length
delLeng = (0:1000)/1000*1.064e-6;
modeMax = 4;
Cmn = cell(modeMax,modeMax);
Cmn(:) = {zeros(size(delLeng))};
totPower = zeros( size(delLeng) );
for il = 1:length(delLeng)
    % change the length from the resonnt point
    imc.props.propList(propID).delL = del0 + delLeng(il);
    % calculate circulating field
    imc.calc( false );
    % calculate HG coefficient
    Cmnval = imc.fields.fieldList(7).HGCoef(0:modeMax-1,0:modeMax-1);
    for icol = 1:modeMax
        for irow = 1:modeMax
            Cmn{icol,irow}(il) = Cmnval(icol,irow);
        end
    end
    % calculate the total power
    totPower(il) = imc.fields.fieldList(7).calcPower;
    if mod( il, 10 ) == 1
        fprintf(1, '%d : length = %g,  total power = %g\n', il, delLeng(il), totPower(il) );
    end
end
figure(1)
semilogy( delLeng, totPower, delLeng, abs(Cmn{1,1}(:)).^2, delLeng, abs(Cmn{2,1}(:)).^2, delLeng, abs(Cmn{1,2}(:)).^2, ...
delLeng, abs(Cmn{3,1}(:)).^2, delLeng, abs(Cmn{2,2}(:)).^2, delLeng, abs(Cmn{1,3}(:)).^2 )
legend('Total', 'TEM00', 'TEM10', 'TEM01', 'TEM20', 'TEM11', 'TEM02');
figure(2)
% to get the field ID 23, which is the one from MC2 to MC1
EMC2 = imc.fields.conv2std(23);
% axis is unique for each field, so get one for field 23
xlMC2 = imc.fields.getXlist(23);
mesh( xlMC2, xlMC2, log(abs(EMC2).^2))

