function fpout = demoFPscan( Ndel )
if ~exist( 'Ndel', 'var' )
    Ndel = 100;
end

% this call FPscan to calculate fields with length between the locked to locked + lambda/2
% build a FP cavity
fp = FPIFO;

% scan cavity modes at these offsets from resonance
% delF = c / lambda(1.064e-6) / arm length (3994.5) * delL = 7.0537e10 * delL
delCav = (0:Ndel)/Ndel/2 * 1.064e-6;

% calculate quantities at different cavity length
% modify FPscan to calculate what you are interested in
fpout = FPscan( fp, delCav );

figure(1)
semilogy( (fpout(:,1)-fpout(1,1))*7.0537e10, fpout(:,2) )
title('Power vs frequency')

% gouy phase in units of (2*pi)
propID = fp.props.findNamedProp('FPprop');
g00r = fp.props.propList( propID ).gouy00 / (2*pi);

% glines is where the resonance should show up
glines =@(n) mod( g00r*n, 0.5 );
% plot power of HOMs
figure(2)
semilogy( (fpout(:,1)-fpout(1,1))/1.064e-6, fpout(:,3:8) )
legend('HOM', 'LG10', 'LG20', 'LG30', 'LG40', 'LG50')
% mark expected resonance points
x1 = glines( 1 );
x2 = glines( 2 );
x3 = glines( 3 );
x4 = glines( 4 );
x5 = glines( 5 );
x6 = glines( 6 );
line( [x1,x2,x3,x4,x5,x6; x1,x2,x3,x4,x5,x6], [ones(1,6)*1e-9; ones(1,6)] );
