%% create FP cavity based on FFTIFO
classdef eLIGORC < FFTIFO
    
    methods
        function defineIFO( obj )
            
            %% add optics
            %  help FFTIFO.addMirror lists all avairable parameters
            
            % laser source
            obj.addLaser( 'src' );
            % RM
            obj.addMirror( 'RM', 'invRoC', 1/15.78e3, 'Aperture', 0.25, 'Thick', 0.1, ...
                'T', 0.03, 'Lhr', 0, 'Lar', 0 );
            % ITM
            obj.addMirror( 'ITM', 'invRoC', 1/14.76e3, 'Aperture', 0.26, 'Thick', 0.1, ...
                'T', 0.03, 'Lhr', 0 );
            % detection port
            obj.addDetector( 'trans' );
            
            %% define connections among optics
            obj.addProp( '', 'src', 'RM-AR' );
            obj.addProp( 'PRC', 'RM-HR', 'ITM-AR', 13);
            obj.addProp( '', 'ITM-HR', 'trans' );
            
            %% modify the defintions of test masses
            %  setTRfiles defines the transmission map, which is negative is optical path length
            %  To add a converging lens, use r^2/(2*RoC) with RoC > 0
            %
            % The third argument is the 2D map of the lens, in which you can use x, y and r.
            % E.g., a spehrical lens can be defined as r.^2/(2*RoC) or (x.^2+y.^2)/(2*RoC)
            % A tilt can be defined as x / x0, or you can combine r.^2/(2*RoC) + x/x0.
            % A user define matlab function can be called. The following example uses a function rmap.
            % The definition of the function is shown at the end of this file.
            %
            % Parameters can be included in the 2D map definition. In the following example, kind is a parameters.
            % A pair of name and default value of the parameter is appended at the end of setTRfiles function.
            % The last two argumensts - 'kind', 1 - is the one for this example.
            % If the 2D map definition has multiple parameters, like RoC and x0 in the example above,
            % append all like 'RoC', 100e3, 'x0', 0.1
            %
            % After you define an IFO as eL = eLIGORC; you can change parameters by
            %     eL.updateMirMaps('ITM', 'kind', 2);
            % An example of scanning by different 'scale' is given in runELIGO.
            %
            obj.setTRfiles( 'ITM', '', 'eLIGORC.rmap(r, kind)', 0.16, 0, 0, 'kind', 1 );
        end
        
        function setupBaseMode( obj )
            % set the mode by the input beam by the size and curvature
            w = 0.0364;
            RoC = 15.78e3 / 1.45;
            qInv = MMTK.RinvW2Qinv( -1/RoC, w );
            portID = obj.optics.findLaser;
            obj.cavities.fillQvals( portID, qInv );
        end
    end
    
    methods (Static)
        
        % example of a function using an interpolation of data
        % three kinds of data can be chonse by the second argument
        function val = rmap( r, kind )
            switch kind
                case 1
                    dat = func1(r);
                case 2
                    dat = func2(r);
                otherwise
                    dat = func3(r);
            end
            % output is interpolation of data
            val = interp1(dat(:,1), dat(:,2), r );
            
            function dat = func1(r)
                dat = zeros(11,2);
                dat(:,1) = (0:10)/10*0.15;
                dat(:,2) = dat(:,1).^2/(2*1e5);
            end
            
            function dat = func2(r)
                dat = zeros(11,2);
                dat(:,1) = (0:10)/10*0.15;
                dat(:,2) = dat(:,1).^2/(2*50e3);
            end
            
            function dat = func3(r)
                dat = zeros(11,2);
                dat(:,1) = (0:10)/10*0.15;
                dat(:,2) = dat(:,1).^2/(2*20e3);
            end
        end
    end
end
