function [E2ITM, xITM, E2ETM, xETM] = fpscat( arm )
% [E2ITM, xITM, E2ETM, xETM] = fpscat( arm )
%   arm = 'X' for X arm, 'Y' for Y arm and 'none' for perfect surface.
% example
% [E2ITMX, xITMX] = fpscat('X');
% [E2ITM0, xITM0] = fpscat('none');
% semilogy( xITMX, abs(E2ITMX(end/2,:)), xITM0, abs(E2ITM0(end/2,:)))

if ~exist('arm', 'var')
    arm = 'X';
end

% run for X arm
% power is the one going into ITM, arm power will be power x 270 or so
fp = FPIFOv('arm', arm, 'power', 1 );

% lock the cavity
fp.lock

% get the field going to ITM
% simulation returns field in wSize x wSize area or wider
% E2ITM is the field going to ITM, units of W/m^2
% E2ITM( iy, ix ) is the field at x (horizontal direction) = xITM(ix), y = xITM(iy).
%        ======= 
wSize = 1;
[E2ITM, xITM] = fp.getField('ITM-HR-i', wSize );
% total power going to ITM
P2ITM = fp.power('ITM-HR-i');

% field to ETM, xETM and xITM can be different
[E2ETM, xETM] = fp.getField('ETM-HR-i', wSize );
% total power going to ETM
P2ETM = fp.power('ETM-HR-i');

fprintf(1,'Power to ITM = %g, power to ETM = %g\n', P2ITM, P2ETM );
% power distribution along horizontal direction
semilogy( xITM, abs(E2ITM(end/2,:)).^2, xETM, abs(E2ETM(end/2,:)).^2 ) ;
legend('Power on ITM', 'power on ETM')
