function prm = onePRMThermal( prm, absSub, absCoat )
% Thermal aberrations are calculated using the following function, see KAGRAPRFPM
%    calcThermal(0 for coating or 1 for substrate, r, PsubIX, PcoatIX, wIX, 0.1, 0.175 )
% For each stationary state, calculate absorptions and update the thermal aberrations
% and calculate the new locked state until the change becomes small, i.e., thermally stational
% To include the RH, set 4 variables invRoC[I,E]TM[X,Y]RH for the 4 RH curvatures

if ~exist('absSub', 'var' )
    absSub = 2e-6*10/100;  % substrate : 2ppm/m for 10cm
end
if ~exist('absCoat', 'var' )
    absCoat = 0.5e-6;      % coating : 0.5ppm
end

doOneArm( 'X', prm, absSub, absCoat );
doOneArm( 'Y', prm, absSub, absCoat );

function doOneArm( arm, prm, absSub, absCoat )
% change thermal aberration for one arm, 'X' or 'Y'
% substrate absorption
ITM = strcat('ITM', arm);
ETM = strcat('ETM', arm);

PsubI = absSub*(prm.power(strcat(ITM,'-AR-i'))+prm.power(strcat(ITM,'-AR-o')));
% coating absorption
PcoatI = absCoat*prm.power(strcat(ITM,'-HR-i'));
% beam size
[~,cwR] = prm.gaussFit(strcat(ITM,'-HR-i')); wITM=(cwR(1).w+cwR(2).w)/2;
% ETM
% coating absorption
PcoatE = absCoat*prm.power(strcat(ETM,'-HR-i'));
% beam size
[~,cwR] = prm.gaussFit(strcat(ETM,'-HR-i')); wETM=(cwR(1).w+cwR(2).w)/2;

% calculate before deformation
RoCI0 = prm.optics.getHRRoC(ITM, wITM*1.5 );
RoCE0 = prm.optics.getHRRoC(ETM, wETM*1.5 );

% change the variables for ITMX and ETMX
prm.updateMirMaps(ITM, strcat('PsubI',arm), PsubI, strcat('PcoatI',arm), PcoatI, strcat('wI',arm), wITM );
prm.updateMirMaps(ETM, strcat('PcoatE',arm), PcoatE, strcat('wE',arm), wETM );

RoCI = prm.optics.getHRRoC(ITM, wITM*1.5 );
RoCE = prm.optics.getHRRoC(ETM, wETM*1.5 );
propID = prm.props.getPropID(strcat(ITM,'-HR-o'));
propLeng = prm.props.getPropLeng( propID );
gouy00 = MMTK.gouy00FP( 1/RoCI, 1/RoCE, propLeng );

fprintf(1, 'Arm %s : PsubI= %g\tPcoatI = %g\twITM = %g\tRoCI = %g -> %g\tPcoatE= %g\twETM= %g\tRoCE = %g -> %g\tgouy00 = %g\n',...
    arm, PsubI, PcoatI, wITM, RoCI0, RoCI, PcoatE, wETM, RoCE0, RoCE, gouy00 );
