function fp = scanTilt( tilts, whichArm, outFile )

outID = 0;
if exist( 'outFile', 'var' )
    outID = fopen(outFile, 'w');
end
if ~exist( 'whichArm', 'var' )
    whichArm = 'Y';
end

% build FP
fp = FPIFOv('arm', whichArm );

% clean ETM tilt
% tilt ITM and ETM to make the shift on ITM to be tilt(:)
ITMRoC = 1934;
ETMRoC = 2245;
L = 3994.5;
delL = zeros(3,1);
for itilt = 1 : length( tilts )
    theta1 = tilts(itilt)/L*(L-ITMRoC)/ITMRoC;
    theta2 = -tilts(itilt)/L;
    fp.updateMirMaps( 'ITM', 'tiltI', theta1 );
    fp.updateMirMaps( 'ETM', 'tiltE', theta2 );
    fp.props.resetDelL;
    if itilt <= 3
        fp.lock(1e-5,0);
        delL(itilt) = fp.props.propList(3).delL;
    else
        delL0 = 3*(delL(3)-delL(2)) + delL(1);
        pList = zeros(3,1);
        ddl = 1.064e-6 / 10000;
        for istep = 1 : 3
            pList(istep) = powerAtDelL( fp, delL0 + ddl*(istep-2), 1e-4 );
        end
        ind0 = 0;  % delL for pList(2) = delL0 + ddl*ind0;
        if pList(1) >  pList(2)
            dir = -1;
        elseif pList(3) > pList(2)
            dir = 1;
        else
            dir = 0;
        end
        % ind0 is not the peak, so find ind0 which is larger than others
        if dir ~= 0
            for istep = 1 : 10000  % try fixed times to avoid infinite loop
                pList = circshift(pList,dir); % shift by one
                ind0 = ind0 + dir; % index for the next pList(2)
                dlscan = delL0 + ddl*(ind0+dir);
                pList(2+dir) = powerAtDelL( fp, dlscan, 1e-4 );
                fprintf(1,'   ind0 = %d, dlscan = %g, power = %g\n', ind0, dlscan*1e6, pList(2+dir));
                if pList(2+dir) < pList(2)
                    break;
                end
            end
        end
        
        ddlscan = (pList(1)-pList(3))/2/(pList(3)-pList(1)-2*pList(2));
        dlscan = ddl*(ind0 + ddlscan);
        
        fp.props.propList(3).delL = delL0 + dlscan;
        fp.props.propList(4).delL = fp.props.propList(3).delL;
        fp.calc(1e-5,0);
        fprintf(1, 'ddlscan = %g, dlscan = %g, power = %g\n', ind0 + ddlscan, dlscan*1e6, fp.power('ITM-HR-i'));
        delL(1:2) = delL(2:3);
        delL(3) = fp.props.propList(3).delL;
    end
    oneAnal( fp, 'ITM & ETM', theta1, outID )
end

%{
% clean ETM tilt
fp.updateMirMaps( 'ETM', 'tiltE', 0 );
% tilt ITM
for itilt = 1 : length( tilts )
    fp.updateMirMaps( 'ITM', 'tiltI', tilts(itilt) );
    fp.lock(1e-5,0);
    oneAnal( fp, 'ITM', tilts(itilt), outID )
end


% clean ITM tilt
fp.updateMirMaps( 'ITM', 'tiltI', 0 );
% tile ETM
for itilt = 1 : length( tilts )
    fp.updateMirMaps( 'ETM', 'tiltE', tilts(itilt) );
    fp.lock(1e-5,0);
    oneAnal( fp, 'ETM', tilts(itilt), outID);
end


% clean ITM and ETM tilt
fp.updateMirMaps( 'ITM', 'tiltI', 0 );
fp.updateMirMaps( 'ETM', 'tiltE', 0 );
% tilt ITM and ETM, common way
for itilt = 1 : length( tilts )
    fp.updateMirMaps( 'ITM', 'tiltI', tilts(itilt) );
    fp.updateMirMaps( 'ETM', 'tiltE', tilts(itilt) );
    fp.lock(1e-5,0);
    oneAnal( fp, 'ITM+ETM', tilts(itilt), outID);
end

% clean ITM and ETM tilt
fp.updateMirMaps( 'ITM', 'tiltI', 0 );
fp.updateMirMaps( 'ETM', 'tiltE', 0 );
% tilt ITM and ETM, differential way
for itilt = 1 : length( tilts )
    fp.updateMirMaps( 'ITM', 'tiltI', tilts(itilt) );
    fp.updateMirMaps( 'ETM', 'tiltE', -tilts(itilt) );
    fp.lock(1e-5,0);
    oneAnal( fp, 'ITM+ETM', tilts(itilt), outID);
end
%}

if outID > 1
    fclose(outID);
end

return

function power = powerAtDelL( fp, delL, err )
fp.props.propList(3).delL = delL;
fp.props.propList(4).delL = fp.props.propList(3).delL;
fp.calc(err,0);
power = fp.power('ITM-HR-i');
return

function oneAnal( fp, whichITM, tiltVal, outID )

HOM = 1 - fp.LGFrac('ITM-HR-o', 0, 0 );
power = fp.power('ITM-HR-o');
RTL = fp.roundtripLoss( 'ITM-HR-o');
[~,cwrI] = fp.gaussFit( 'ITM-HR-i' );
[~,cwrE] = fp.gaussFit( 'ETM-HR-i' );
[L0, delL] = fp.getPropLeng( 'FPprop' );
delL = delL * 1e6;
lossI = fp.fields.lossOut('ITM-HR-i');
lossE = fp.fields.lossOut('ETM-HR-i');
fprintf(1, '%s > tilt = %g (urad), delL = %g (um), offITM = %g (cm), offETM = %g (cm)\n   RTL = %g (ppm), loss(I) = %g (ppm), loss(E) = %g (ppm), power = %g, HOM = %g\n', ...
    whichITM, tiltVal*1e6, delL, cwrI(1).c0*100, cwrE(1).c0*100, RTL*1e6, lossI*1e6, lossE*1e6, power, HOM );
if outID > 1
    fprintf(outID, '%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\n', ...
        tiltVal*1e6, delL, cwrI(1).c0*100, cwrE(1).c0*100, RTL*1e6, lossI*1e6, lossE*1e6, power, HOM );
end
