function [fp, epsP] = thermalLoop( fp, maxLoop, epsLimit )
% function [fp, epsP] = thermalLoop( fp, maxLoop, epsLimit)

if ~exist( 'maxLoop', 'var' )
    maxLoop = 10;
end
if ~exist( 'epsLimit', 'var' )
    epsLimit = 1e-5;
end

Pold = fp.power('ETMX-HR-o');
for iloop = 1:maxLoop
    fp = oneLoop( fp );
    Pnew = fp.power('ETMX-HR-o');
    fprintf(1,'Power changed from %g to %g\n', Pold, Pnew);
    epsP = abs(Pnew/Pold-1);
    if epsP < epsLimit
        fprintf(1,'Power change converged (%g) and exits after %d iretation\n\n', epsP, iloop);
        break;
    end
    Pold = Pnew;
end

function fp = oneLoop( fp )

absSub = 4.7e-6*10;  % 2ppm/m for 20cm
absCoat = 0.5e-6;   % 0.3ppm

PsubIX = absSub*(fp.power('ITMX-AR-i')+fp.power('ITMX-AR-o'));
PcoatIX = absCoat*fp.power('ITMX-HR-i');
[~,cwR] = fp.gaussFit('ITMX-HR-i'); wITMX=(cwR(1).w+cwR(2).w)/2;
PcoatEX = absCoat*fp.power('ETMX-HR-i');
[~,cwR] = fp.gaussFit('ETMX-HR-i'); wETMX=(cwR(1).w+cwR(2).w)/2;

fprintf(1, 'PsubIX= %g\tPcoatID= %g\twITMX= %g\tPcoatEX= %g\twETMX= %g\n',...
    PsubIX, PcoatIX, wITMX, PcoatEX, wETMX );

fp.updateMirMaps('ITMX', 'PsubIX', PsubIX, 'PcoatIX', PcoatIX, 'wIX', wITMX );
fp.updateMirMaps('ETMX', 'PcoatEX', PcoatEX, 'wEX', wETMX );
fp.lock(1e-5,0); % accuracy 1e-5, no print out of progress information

